#ifndef __SPLINEH__
#define __SPLINEH__
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 S P L I N E   R O U T I N E S 
 
 interface part to adaptive spline routines
 from the AMS library
 
 Peter Beerli 1999, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: spline.h,v 1.9 2003/11/04 16:12:10 beerli Exp $
-------------------------------------------------------*/

extern int dbvssc_ (double *x, double *y, long *np, long *n, long *k,
                        long *opt, double *d0, double *dnp, double *d20,
                        double *d2np, long *constr, double *eps,
                        double (*beta) (), double (*betai) (), double (*rho) (),
                        double (*rhoi) (), long *kmax, long *maxstp, long *errc,
                        double *d, double *d2, long *diagn, double *work,
                        long *nwork);

extern int dbvsse_ (double *x, double *y, long *np, long *n, long *k,
                        double *xtab, long *ntab, long *sbopt, long *y0opt,
                        long *y1opt, long *y2opt, long *errc, double *d,
                        double *d2, double *y0tab, double *y1tab, double *y2tab,
                        long *erre, double *work, long *nwork);



#endif
